@@ -2,7 +2,6 @@ import sys
 
 from . import settings  # noqa: F401 # imported but unused
 from .settings import (  # noqa: F401 # imported but unused
-    prefix,
     Settings,
     Setting,
     PropertySetting,
@@ -38,4 +37,4 @@ def _load_contrib():
 _load_contrib()
 
 
-__version__ = "0.0.6"
+__version__ = "0.1"
